@@ -6,7 +6,9 @@ from pyrogram import raw
 
 class CloseForumTopic:
     async def close_forum_topic(
-        self: pyrogram.Client, chat_id: int | str, topic_id: int
+        self: pyrogram.Client,
+        chat_id: int | str,
+        topic_id: int,
     ) -> bool:
         """Close a forum topic.
 
@@ -33,6 +35,6 @@ class CloseForumTopic:
                 channel=await self.resolve_peer(chat_id),
                 topic_id=topic_id,
                 closed=True,
-            )
+            ),
         )
         return True
