@@ -6,7 +6,8 @@ from pyrogram import raw
 
 class GetChatOnlineCount:
     async def get_chat_online_count(
-        self: pyrogram.Client, chat_id: int | str
+        self: pyrogram.Client,
+        chat_id: int | str,
     ) -> int:
         """Get the number of members that are currently online in a chat.
 
@@ -29,7 +30,7 @@ class GetChatOnlineCount:
         return (
             await self.invoke(
                 raw.functions.messages.GetOnlines(
-                    peer=await self.resolve_peer(chat_id)
-                )
+                    peer=await self.resolve_peer(chat_id),
+                ),
             )
         ).onlines
