@@ -6,7 +6,8 @@ from pyrogram import raw, types
 
 class GetSendAsChats:
     async def get_send_as_chats(
-        self: pyrogram.Client, chat_id: int | str
+        self: pyrogram.Client,
+        chat_id: int | str,
     ) -> list[types.Chat]:
         """Get the list of "send_as" chats available.
 
@@ -27,7 +28,7 @@ class GetSendAsChats:
                 print(chats)
         """
         r = await self.invoke(
-            raw.functions.channels.GetSendAs(peer=await self.resolve_peer(chat_id))
+            raw.functions.channels.GetSendAs(peer=await self.resolve_peer(chat_id)),
         )
 
         users = {u.id: u for u in r.users}
@@ -38,11 +39,11 @@ class GetSendAsChats:
         for p in r.peers:
             if isinstance(p.peer, raw.types.PeerUser):
                 send_as_chats.append(
-                    types.Chat._parse_chat(self, users[p.peer.user_id])
+                    types.Chat._parse_chat(self, users[p.peer.user_id]),
                 )
             else:
                 send_as_chats.append(
-                    types.Chat._parse_chat(self, chats[p.peer.channel_id])
+                    types.Chat._parse_chat(self, chats[p.peer.channel_id]),
                 )
 
         return send_as_chats
