@@ -6,7 +6,9 @@ from pyrogram import raw
 
 class SetChatDescription:
     async def set_chat_description(
-        self: pyrogram.Client, chat_id: int | str, description: str
+        self: pyrogram.Client,
+        chat_id: int | str,
+        description: str,
     ) -> bool:
         """Change the description of a supergroup or a channel.
         You must be an administrator in the chat for this to work and must have the appropriate admin rights.
@@ -39,7 +41,7 @@ class SetChatDescription:
             raw.types.InputPeerChannel | raw.types.InputPeerChat,
         ):
             await self.invoke(
-                raw.functions.messages.EditChatAbout(peer=peer, about=description)
+                raw.functions.messages.EditChatAbout(peer=peer, about=description),
             )
         else:
             raise ValueError(f'The chat_id "{chat_id}" belongs to a user')
