@@ -30,14 +30,15 @@ async def get_session(client: pyrogram.Client, dc_id: int):
 
         for _ in range(3):
             exported_auth = await client.invoke(
-                raw.functions.auth.ExportAuthorization(dc_id=dc_id)
+                raw.functions.auth.ExportAuthorization(dc_id=dc_id),
             )
 
             try:
                 await session.invoke(
                     raw.functions.auth.ImportAuthorization(
-                        id=exported_auth.id, bytes=exported_auth.bytes
-                    )
+                        id=exported_auth.id,
+                        bytes=exported_auth.bytes,
+                    ),
                 )
             except AuthBytesInvalid:
                 continue
