@@ -40,6 +40,7 @@ class SendMediaGroup:
         parse_mode: enums.ParseMode | None = None,
         schedule_date: datetime | None = None,
         protect_content: bool | None = None,
+        allow_paid_broadcast: bool | None = None,
         message_effect_id: int | None = None,
         invert_media: bool | None = None,
     ) -> list[types.Message]:
@@ -73,7 +74,7 @@ class SendMediaGroup:
                 If the message is a reply, ID of the original message.
 
             reply_to_story_id (``int``, *optional*):
-                Unique identifier for the target story.
+                If the message is a reply, ID of the target story.
 
             reply_to_chat_id (``int`` | ``str``, *optional*):
                 Unique identifier for the origin chat.
@@ -99,6 +100,9 @@ class SendMediaGroup:
             protect_content (``bool``, *optional*):
                 Protects the contents of the sent message from forwarding and saving.
 
+            allow_paid_broadcast (``bool``, *optional*):
+                Pass True to allow the message to ignore regular broadcast limits for a small fee; for bots only.
+
             message_effect_id (``int`` ``64-bit``, *optional*):
                 Unique identifier of the message effect to be added to the message; for private chats only.
 
@@ -147,7 +151,7 @@ class SendMediaGroup:
                                     file=await self.save_file(i.media),
                                     spoiler=i.has_spoiler,
                                 ),
-                            )
+                            ),
                         )
 
                         media = raw.types.InputMediaPhoto(
@@ -163,9 +167,10 @@ class SendMediaGroup:
                             raw.functions.messages.UploadMedia(
                                 peer=await self.resolve_peer(chat_id),
                                 media=raw.types.InputMediaPhotoExternal(
-                                    url=i.media, spoiler=i.has_spoiler
+                                    url=i.media,
+                                    spoiler=i.has_spoiler,
                                 ),
-                            )
+                            ),
                         )
 
                         media = raw.types.InputMediaPhoto(
@@ -178,7 +183,8 @@ class SendMediaGroup:
                         )
                     else:
                         media = utils.get_input_media_from_file_id(
-                            i.media, FileType.PHOTO
+                            i.media,
+                            FileType.PHOTO,
                         )
                 else:
                     media = await self.invoke(
@@ -188,7 +194,7 @@ class SendMediaGroup:
                                 file=await self.save_file(i.media),
                                 spoiler=i.has_spoiler,
                             ),
-                        )
+                        ),
                     )
 
                     media = raw.types.InputMediaPhoto(
@@ -207,7 +213,7 @@ class SendMediaGroup:
                             videoInfo = MediaInfo.parse(i.media)
                         except OSError:
                             is_animation = bool(
-                                isinstance(i, types.InputMediaAnimation)
+                                isinstance(i, types.InputMediaAnimation),
                             )
                         else:
                             if not any(
@@ -225,7 +231,7 @@ class SendMediaGroup:
                                 h=i.height,
                             ),
                             raw.types.DocumentAttributeFilename(
-                                file_name=Path(i.media).name
+                                file_name=Path(i.media).name,
                             ),
                         ]
                         if is_animation:
@@ -242,7 +248,7 @@ class SendMediaGroup:
                                     nosound_video=is_animation,
                                     attributes=attributes,
                                 ),
-                            )
+                            ),
                         )
 
                         media = raw.types.InputMediaDocument(
@@ -258,9 +264,10 @@ class SendMediaGroup:
                             raw.functions.messages.UploadMedia(
                                 peer=await self.resolve_peer(chat_id),
                                 media=raw.types.InputMediaDocumentExternal(
-                                    url=i.media, spoiler=i.has_spoiler
+                                    url=i.media,
+                                    spoiler=i.has_spoiler,
                                 ),
-                            )
+                            ),
                         )
 
                         media = raw.types.InputMediaDocument(
@@ -273,7 +280,8 @@ class SendMediaGroup:
                         )
                     else:
                         media = utils.get_input_media_from_file_id(
-                            i.media, FileType.VIDEO
+                            i.media,
+                            FileType.VIDEO,
                         )
                 else:
                     media = await self.invoke(
@@ -284,7 +292,7 @@ class SendMediaGroup:
                                 thumb=await self.save_file(i.thumb),
                                 spoiler=i.has_spoiler,
                                 mime_type=self.guess_mime_type(
-                                    getattr(i.media, "name", "video.mp4")
+                                    getattr(i.media, "name", "video.mp4"),
                                 )
                                 or "video/mp4",
                                 attributes=[
@@ -300,11 +308,11 @@ class SendMediaGroup:
                                             i.media,
                                             "name",
                                             "video.mp4",
-                                        )
+                                        ),
                                     ),
                                 ],
                             ),
-                        )
+                        ),
                     )
 
                     media = raw.types.InputMediaDocument(
@@ -333,11 +341,11 @@ class SendMediaGroup:
                                             title=i.title,
                                         ),
                                         raw.types.DocumentAttributeFilename(
-                                            file_name=Path(i.media).name
+                                            file_name=Path(i.media).name,
                                         ),
                                     ],
                                 ),
-                            )
+                            ),
                         )
 
                         media = raw.types.InputMediaDocument(
@@ -345,16 +353,16 @@ class SendMediaGroup:
                                 id=media.document.id,
                                 access_hash=media.document.access_hash,
                                 file_reference=media.document.file_reference,
-                            )
+                            ),
                         )
                     elif re.match("^https?://", i.media):
                         media = await self.invoke(
                             raw.functions.messages.UploadMedia(
                                 peer=await self.resolve_peer(chat_id),
                                 media=raw.types.InputMediaDocumentExternal(
-                                    url=i.media
+                                    url=i.media,
                                 ),
-                            )
+                            ),
                         )
 
                         media = raw.types.InputMediaDocument(
@@ -362,11 +370,12 @@ class SendMediaGroup:
                                 id=media.document.id,
                                 access_hash=media.document.access_hash,
                                 file_reference=media.document.file_reference,
-                            )
+                            ),
                         )
                     else:
                         media = utils.get_input_media_from_file_id(
-                            i.media, FileType.AUDIO
+                            i.media,
+                            FileType.AUDIO,
                         )
                 else:
                     media = await self.invoke(
@@ -374,7 +383,7 @@ class SendMediaGroup:
                             peer=await self.resolve_peer(chat_id),
                             media=raw.types.InputMediaUploadedDocument(
                                 mime_type=self.guess_mime_type(
-                                    getattr(i.media, "name", "audio.mp3")
+                                    getattr(i.media, "name", "audio.mp3"),
                                 )
                                 or "audio/mpeg",
                                 file=await self.save_file(i.media),
@@ -390,11 +399,11 @@ class SendMediaGroup:
                                             i.media,
                                             "name",
                                             "audio.mp3",
-                                        )
+                                        ),
                                     ),
                                 ],
                             ),
-                        )
+                        ),
                     )
 
                     media = raw.types.InputMediaDocument(
@@ -402,7 +411,7 @@ class SendMediaGroup:
                             id=media.document.id,
                             access_hash=media.document.access_hash,
                             file_reference=media.document.file_reference,
-                        )
+                        ),
                     )
             elif isinstance(i, types.InputMediaDocument):
                 if isinstance(i.media, str):
@@ -417,11 +426,11 @@ class SendMediaGroup:
                                     thumb=await self.save_file(i.thumb),
                                     attributes=[
                                         raw.types.DocumentAttributeFilename(
-                                            file_name=Path(i.media).name
-                                        )
+                                            file_name=Path(i.media).name,
+                                        ),
                                     ],
                                 ),
-                            )
+                            ),
                         )
 
                         media = raw.types.InputMediaDocument(
@@ -429,16 +438,16 @@ class SendMediaGroup:
                                 id=media.document.id,
                                 access_hash=media.document.access_hash,
                                 file_reference=media.document.file_reference,
-                            )
+                            ),
                         )
                     elif re.match("^https?://", i.media):
                         media = await self.invoke(
                             raw.functions.messages.UploadMedia(
                                 peer=await self.resolve_peer(chat_id),
                                 media=raw.types.InputMediaDocumentExternal(
-                                    url=i.media
+                                    url=i.media,
                                 ),
-                            )
+                            ),
                         )
 
                         media = raw.types.InputMediaDocument(
@@ -446,11 +455,12 @@ class SendMediaGroup:
                                 id=media.document.id,
                                 access_hash=media.document.access_hash,
                                 file_reference=media.document.file_reference,
-                            )
+                            ),
                         )
                     else:
                         media = utils.get_input_media_from_file_id(
-                            i.media, FileType.DOCUMENT
+                            i.media,
+                            FileType.DOCUMENT,
                         )
                 else:
                     media = await self.invoke(
@@ -458,7 +468,7 @@ class SendMediaGroup:
                             peer=await self.resolve_peer(chat_id),
                             media=raw.types.InputMediaUploadedDocument(
                                 mime_type=self.guess_mime_type(
-                                    getattr(i.media, "name", "file.zip")
+                                    getattr(i.media, "name", "file.zip"),
                                 )
                                 or "application/zip",
                                 file=await self.save_file(i.media),
@@ -469,11 +479,11 @@ class SendMediaGroup:
                                             i.media,
                                             "name",
                                             "file.zip",
-                                        )
-                                    )
+                                        ),
+                                    ),
                                 ],
                             ),
-                        )
+                        ),
                     )
 
                     media = raw.types.InputMediaDocument(
@@ -481,11 +491,11 @@ class SendMediaGroup:
                             id=media.document.id,
                             access_hash=media.document.access_hash,
                             file_reference=media.document.file_reference,
-                        )
+                        ),
                     )
             else:
                 raise ValueError(
-                    f"{i.__class__.__name__} is not a supported type for send_media_group"
+                    f"{i.__class__.__name__} is not a supported type for send_media_group",
                 )
 
             multi_media.append(
@@ -493,7 +503,7 @@ class SendMediaGroup:
                     media=media,
                     random_id=self.rnd_id(),
                     **await self.parser.parse(i.caption, i.parse_mode),
-                )
+                ),
             )
 
         rpc = raw.functions.messages.SendMultiMedia(
@@ -503,6 +513,7 @@ class SendMediaGroup:
             reply_to=reply_to,
             schedule_date=utils.datetime_to_timestamp(schedule_date),
             noforwards=protect_content,
+            allow_paid_floodskip=allow_paid_broadcast,
             effect=message_effect_id,
             invert_media=invert_media,
         )
@@ -510,7 +521,8 @@ class SendMediaGroup:
         if business_connection_id is not None:
             r = await self.invoke(
                 raw.functions.InvokeWithBusinessConnection(
-                    connection_id=business_connection_id, query=rpc
+                    connection_id=business_connection_id,
+                    query=rpc,
                 ),
                 sleep_threshold=60,
             )
