@@ -27,6 +27,6 @@ class BlockUser:
         """
         return bool(
             await self.invoke(
-                raw.functions.contacts.Block(id=await self.resolve_peer(user_id))
-            )
+                raw.functions.contacts.Block(id=await self.resolve_peer(user_id)),
+            ),
         )
