@@ -12,7 +12,10 @@ class RunSync:
     Result = TypeVar("Result")
 
     async def run_sync(
-        self, func: Callable[..., Result], *args: Any, **kwargs: Any
+        self,
+        func: Callable[..., Result],
+        *args: Any,
+        **kwargs: Any,
     ) -> Result:
         """Runs the given sync function (optionally with arguments) on a separate thread.
 
