@@ -22,7 +22,9 @@ class GzipPacked(TLObject):
     @staticmethod
     def read(data: BytesIO, *args: Any) -> GzipPacked:  # noqa: ARG004
         # Return the Object itself instead of a GzipPacked wrapping it
-        return cast(GzipPacked, TLObject.read(BytesIO(decompress(Bytes.read(data)))))
+        return cast(
+            "GzipPacked", TLObject.read(BytesIO(decompress(Bytes.read(data))))
+        )
 
     def write(self, *args: Any) -> bytes:  # noqa: ARG002
         b = BytesIO()
