@@ -12,7 +12,7 @@ if TYPE_CHECKING:
 class Double(bytes, TLObject):
     @classmethod
     def read(cls, data: BytesIO, *args: Any) -> float:  # noqa: ARG003
-        return cast(float, unpack("d", data.read(8))[0])
+        return cast("float", unpack("d", data.read(8))[0])
 
     def __new__(cls, value: float) -> bytes:  # type: ignore
         return pack("d", value)
