@@ -11,7 +11,9 @@ if TYPE_CHECKING:
 class String(Bytes):
     @classmethod
     def read(cls, data: BytesIO, *args) -> str:  # noqa: ARG003
-        return cast(bytes, super(String, String).read(data)).decode(errors="replace")
+        return cast("bytes", super(String, String).read(data)).decode(
+            errors="replace"
+        )
 
     def __new__(cls, value: str) -> bytes:
         return super().__new__(cls, value.encode())
