@@ -16,7 +16,7 @@ class TLObject:
 
     @classmethod
     def read(cls, b: BytesIO, *args: Any) -> Any:
-        return cast(TLObject, objects[int.from_bytes(b.read(4), "little")]).read(
+        return cast("TLObject", objects[int.from_bytes(b.read(4), "little")]).read(
             b,
             *args,
         )
