@@ -22,5 +22,5 @@ class BotCommandScopeChatAdministrators(BotCommandScope):
 
     async def write(self, client: pyrogram.Client) -> raw.base.BotCommandScope:
         return raw.types.BotCommandScopePeerAdmins(
-            peer=await client.resolve_peer(self.chat_id)
+            peer=await client.resolve_peer(self.chat_id),
         )
