@@ -25,5 +25,5 @@ class SentWebAppMessage(Object):
     @staticmethod
     def _parse(obj: raw.types.WebViewMessageSent):
         return SentWebAppMessage(
-            inline_message_id=utils.pack_inline_message_id(obj.msg_id)
+            inline_message_id=utils.pack_inline_message_id(obj.msg_id),
         )
